#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-KkfmETzdxBpJOjrBNh1pVl
key:                  coinbase-pro-0.9.3.2-KkfmETzdxBpJOjrBNh1pVl
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  a835655b7c47dc0ceb062d58dd1bcf7c
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-KkfmETzdxBpJOjrBNh1pVl
depends:
    HsOpenSSL-0.11.7.10-Gq95SmCRnqyIBB2zP88vX5
    aeson-2.2.2.0-Fs8lpfl0CTvIUZfvQfMaj3
    aeson-casing-0.2.0.0-Im9AzzlYrrionvyHfkiOC
    async-2.2.6-GtVZdAjyiB3HTVxVSGqO8l base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-C7CiOkmAx4nlLzrbDZkuq exceptions-0.10.7
    http-api-data-0.6.1-4FmZSRAyaEaCYH46bSmgSM
    http-client-0.7.19-DALlHG22JR86LK61BczJck
    http-client-tls-0.3.6.4-9aLPLbyXiQrLJlGR6hoZq5
    http-streams-0.8.9.9-DnQzkM1366u3nHBAn9J9k5
    http-types-0.12.4-LNdcYYtCiEAAA2abLyIqKh
    io-streams-1.5.2.2-7LaMf5DdnjG2Aw9ED5zS3U
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-2vzg6cg8x4bL2vbL886yck
    servant-0.20.3.0-KJU3UZohd974uU1pX6z1fu
    servant-client-0.20.3.0-Fs3g5uVNTkl3LXjU14SrrR
    servant-client-core-0.20.3.0-6Z13yqVOo6mKaziuxHfcgu
    tasty-1.5.3-AzHeewJiLP68tKN5TZJG9J
    tasty-hunit-0.10.2-7BhJPMfB87wEZNvC7HcdQY text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-Ju8weNNZsO4EqUXE1uEAtj
    unordered-containers-0.2.21-DZIhPqSL0N2YNV8fYQEJ8
    uuid-1.3.16.1-8AfjkJYpZ1yBTyP6oomz5p
    vector-0.13.2.0-746bkLFippyHVcwUkeKsy
    websockets-0.12.7.3-GUqiL5swwWcK2ZeLWlvSwC
    wuss-2.0.1.7-GxcbmHlxkmJ86AugysfQQB

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

